import os
import unittest
from unittest import TestCase
import xml.etree.ElementTree as ET
from builder.converter.views import write_to_disk


class TestViews(TestCase):

    current_dir = os.path.dirname(os.path.realpath(__file__))
    file_path = os.path.join(current_dir + "/%s")

    @unittest.skip('Unfinished')
    def test_should_write_to_disk(self):
        view_xml = open(self.file_path % 'list_view.xml')
        xml = view_xml.read()

        view_name = ET.fromstring(xml).find('name').text
        path = "views"
        write_to_disk(xml, path)

        written_file = open(os.path.join(path, 'monsanto.xml'), 'r')
        disk_xml = written_file.read()

        self.assertEqual(disk_xml, xml)



import requests
import ConfigParser
import argparse
import os
import sys
import re

headers = {'Content-type': 'text/xml'}


def post(url, payload, config):
    response = requests.post(url,
                             data=payload,
                             headers=headers,
                             auth=(config['user'],
                                   config['password']),
                             verify=False)
    if response.status_code != 200:
        print response.text


def update(config, view_name, view_xml):
        get_url = config['url'] + '/view/%s' % view_name
        create_url = config['url'] + '/createView?name=%s' % view_name
        update_url = get_url + '/config.xml'
        response = requests.get(get_url, verify=False)
        if response.status_code != 200:
            print "Creating view %s" % view_name
            post(create_url, view_xml, config)
        else:
            print "Updating view %s" % view_name
            post(update_url, view_xml, config)



import yaml
from converter_mapping import converters

def convert_to_xml(yaml_str):
    yaml_dict = yaml.load(yaml_str)
    try:
        view_type = yaml_dict[0]['view']['type']
    except:
        raise Exception('View type %s not supported' % view_type)
    return converters[view_type](yaml_str)



import os
import shutil
import ConfigParser
import logging
import sys
import argparse

from cliff.command import Command
from builder.converter.converter import convert_to_xml
from builder.uploader.jenkins_upload import update


class Test(Command):
    "Spits out the generated xmls in the out folder of cwd"

    log = logging.getLogger(__name__)

    def get_parser(self, prog_name):
        parser = argparse.ArgumentParser(description="Parser")
        parser.add_argument("yaml",
                            type=str,
                            help="Path to the view yaml file")
        return parser

    def take_action(self, parsed_args):
        with open(os.path.join(parsed_args.yaml), 'r') as yaml_file:
            yaml = yaml_file.read()
            self.log.debug(yaml)

        try:
            name, xml = convert_to_xml(yaml)
        except Exception as e:
            raise(e)
        if os.path.isdir("out"):
            shutil.rmtree("out", ignore_errors=True)
        os.makedirs("out")
        with open(os.path.join("out", name + ".xml"), 'w') as xml_file:
            xml_file.write(xml)



import yaml
import os
import xml.etree.ElementTree as ET


def convert_to_xml(yaml_str):
    yaml_dict = yaml.load(yaml_str)
    current_dir = os.path.dirname(os.path.realpath(__file__))
    template_path = os.path.join(
        current_dir, 'templates/pipeline_view_template.xml')
    root = ET.parse(template_path).getroot()
    set_name(root, yaml_dict)
    set_title(root, yaml_dict)
    set_first_job(root, yaml_dict)
    set_displayed_builds(root, yaml_dict)
    set_refresh_frequency(root, yaml_dict)
    set_trigger_only_latest(root, yaml_dict)
    set_pipeline_params(root, yaml_dict)
    set_allow_manual_trigger(root, yaml_dict)
    xml = ET.tostring(root, method='xml', encoding="us-ascii")
    return (yaml_dict[0]['view']['name'],
            "<?xml version=\"1.0\" ?>" + xml)


def set_name(root, yaml_dict):
    name = root.find('name')
    name.text = yaml_dict[0]['view']['name']


def set_title(root, yaml_dict):
    title = root.find('buildViewTitle')
    title.text = yaml_dict[0]['view']['title']


def set_first_job(root, yaml_dict):
    first_job = root.find('gridBuilder/firstJob')
    first_job.text = yaml_dict[0]['view']['first_job']


def set_displayed_builds(root, yaml_dict):
    displayed_builds = root.find('noOfDisplayedBuilds')
    displayed_builds.text = str(yaml_dict[0]['view']['no_of_displayed_builds'])


def set_refresh_frequency(root, yaml_dict):
    refresh_frequency = root.find('refreshFrequency')
    refresh_frequency.text = str(yaml_dict[0]['view']['refresh_frequency'])


def set_trigger_only_latest(root, yaml_dict):
    trigger_only_latest = root.find('triggerOnlyLatestJob')
    trigger_only_latest.text = 'true' if str(
        yaml_dict[0]['view']['trigger_only_latest']) else 'false'


def set_pipeline_params(root, yaml_dict):
    show_pipeline_params = root.find('showPipelineParameters')
    starts_with_params = root.find('startsWithParameters')
    show_pipeline_params_headers = root.find('showPipelineParametersInHeaders')
    show_pipeline_defn_header = root.find('showPipelineDefinitionHeader')

    view = yaml_dict[0]['view']

    show_pipeline_params.text = 'true'  if view['show_pipeline_parameters'] else 'false'
    starts_with_params.text = 'true' if view['starts_with_parameters'] else 'false'
    show_pipeline_params_headers.text = 'true' if view['show_pipeline_parameters_in_headers'] else 'false'
    show_pipeline_defn_header.text = 'true' if view['show_pipeline_definition_header'] else 'false'


def set_allow_manual_trigger(root, yaml_dict):
    allow_manual_trigger = root.find('alwaysAllowManualTrigger')
    allow_manual_trigger.text = 'true' if str(
        yaml_dict[0]['view']['always_allow_manual_trigger']) else 'false'



mapping = {
    'status': 'hudson.views.StatusColumn',
    'weather': 'hudson.views.WeatherColumn',
    'job': 'hudson.views.JobColumn',
    'last_success': 'hudson.views.LastSuccessColumn',
    'last_failure': 'hudson.views.LastFailureColumn',
    'last_duration': 'hudson.views.LastDurationColumn',
    'build_button': 'hudson.views.BuildButtonColumn'
    }



import os
from unittest import TestCase
import xml.etree.ElementTree as ET
from builder.converter.converter import convert_to_xml
from builder.converter.list_view import create_job_element
from builder.converter.list_view import create_column_element


class TestListView(TestCase):

    current_dir = os.path.dirname(os.path.realpath(__file__))
    file_path = os.path.join(current_dir, "fixtures")

    def test_should_have_a_name_tag_in_view_xml(self):
        yaml_file = open(os.path.join(self.file_path, 'list_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)
        name = xml_root.find('name')

        self.assertEqual(name.text, 'monsanto')

    def test_should_have_jobs_in_view_xml(self):
        yaml_file = open(os.path.join(self.file_path, 'list_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)
        jobs = xml_root.findall('jobNames/string')
        jobs = [job.text for job in jobs]

        self.assertListEqual(jobs, ['Merge-nova-Ply',
                                    'Merge-config-Ply',
                                    'Merge-bark-Ply'])

    def test_should_have_columns_in_view_xml(self):
        yaml_file = open(os.path.join(self.file_path, 'list_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)
        columns = xml_root.findall('columns/')
        column_tags = [column.tag for column in columns]

        self.assertListEqual(column_tags, ['hudson.views.StatusColumn',
                                           'hudson.views.WeatherColumn'])

    def test_should_include_recurse_flag_in_xml(self):
        yaml_file = open(os.path.join(self.file_path, 'list_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)
        recurse = xml_root.find('recurse')

        self.assertEqual(recurse.text, 'false')

    def test_should_include_description_in_xml(self):
        yaml_file = open(os.path.join(self.file_path, 'list_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)
        description = xml_root.find('description')

        self.assertEqual(description.text, 'Merge ply jobs')

    def test_should_create_a_job_element_given_job_name(self):
        job_name = 'jobyjob'
        element = create_job_element(job_name)
        self.assertEqual(element.text, job_name)

    def test_should_create_a_column_element_given_name(self):
        column_name = 'status'
        expected_name = 'hudson.views.StatusColumn'
        element = create_column_element(column_name)
        self.assertEqual(element.tag, expected_name)

    def test_should_raise_an_exception_given_a_bad_column_name(self):
        column_name = 'other'
        self.assertRaises(Exception,
                          lambda: create_column_element(column_name))



import os
from unittest import TestCase
from builder.converter.converter import convert_to_xml

class TestConverter(TestCase):

    current_dir = os.path.dirname(os.path.realpath(__file__))
    file_path = os.path.join(current_dir, "fixtures")

    def test_should_raise_exception_for_invalid_view_type(self):
        yaml_file = open(os.path.join(self.file_path, 'invalid_view_type.yaml'), 'r')

        yaml = yaml_file.read()

        self.assertRaises(lambda: convert_to_xml(yaml))



import os
import xml.etree.ElementTree as ET


def write_to_disk(xml, path):
    view_xml = ET.fromstring(xml)
    view_name = view_xml.find('name').text
    with open(os.path.join(path, view_name + ".xml"), 'w') as view_file:
        view_file.write(xml)



import os
from unittest import TestCase
import xml.etree.ElementTree as ET
from builder.converter.converter import convert_to_xml


class TestPipelineView(TestCase):

    current_dir = os.path.dirname(os.path.realpath(__file__))
    file_path = os.path.join(current_dir, "fixtures")

    def test_should_have_name_tag_in_view_xml(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        name = xml_root.find('name')

        self.assertEqual(name.text, 'monsanto')

    def test_should_have_title_in_view_xml(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        name = xml_root.find('buildViewTitle')

        self.assertEqual(name.text, 'build pipeline')

    def test_should_have_first_job_of_the_pipeline(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        first_job = xml_root.find('gridBuilder/firstJob')

        self.assertEqual(first_job.text, 'joby job')

    def test_should_include_number_of_displayed_builds(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        displayed_builds = xml_root.find('noOfDisplayedBuilds')

        self.assertEqual(displayed_builds.text, '20')

    def test_should_set_refresh_frequency(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        refresh_frequency = xml_root.find('refreshFrequency')

        self.assertEqual(refresh_frequency.text, '5')

    def test_should_trigger_only_latest(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        trigger_latest = xml_root.find('triggerOnlyLatestJob')

        self.assertEqual(trigger_latest.text, 'true')

    def test_should_set_pipeline_parameters(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        show_pipeline_params = xml_root.find('showPipelineParameters')
        show_pipeline_params_headers = xml_root.find('showPipelineParametersInHeaders')
        starts_with_params = xml_root.find('startsWithParameters')
        show_pipeline_defn_header = xml_root.find('showPipelineDefinitionHeader')

        self.assertEqual(show_pipeline_params.text, 'false')
        self.assertEqual(show_pipeline_params_headers.text, 'false')
        self.assertEqual(starts_with_params.text, 'false')
        self.assertEqual(show_pipeline_defn_header.text, 'false')

    def test_should_set_allow_manual_trigger(self):
        yaml_file = open(os.path.join(self.file_path, 'pipeline_view.yaml'), 'r')

        yaml = yaml_file.read()

        name, xml_view = convert_to_xml(yaml)
        xml_root = ET.fromstring(xml_view)

        always_allow_manual_trigger = xml_root.find('alwaysAllowManualTrigger')

        self.assertEqual(always_allow_manual_trigger.text, 'true')



import os
import ConfigParser
import logging
import sys
import argparse

from cliff.command import Command
from builder.converter.converter import convert_to_xml
from builder.uploader.jenkins_upload import update


class Update(Command):
    "Command for updating views on jenkins"

    log = logging.getLogger(__name__)

    def get_parser(self, prog_name):
        parser = argparse.ArgumentParser(description="Parser")
        parser.add_argument("--conf",
                            type=str,
                            help="Path to the jenkins config file")
        parser.add_argument("yaml",
                            type=str,
                            help="Path to the view yaml file")
        return parser

    def read_update(self, config, view_yaml):
        with open(view_yaml, 'r') as yaml_file:
            yaml = yaml_file.read()
            self.log.debug(yaml)
            name, xml = convert_to_xml(yaml)
            self.log.debug(xml)
            update(config, name, xml)

    def take_action(self, parsed_args):
        self.log.info("Updating view data in Jenkins")
        if not parsed_args.conf:
            print parser.print_help()
            sys.exit(1)
        config = self.parse_config(parsed_args.conf)
        yaml_file = os.path.join(parsed_args.yaml)

        if os.path.isdir(yaml_file):
            views = [view for view in os.listdir(yaml_file)]
            for view_yaml in views:
                self.log.debug("View file %s" % view_yaml)
                self.read_update(config,
                                 os.path.join(yaml_file + '/%s' % view_yaml))
        else:
            self.log.debug("View file %s" % yaml_file)
            self.read_update(config, os.path.join(yaml_file))

    def parse_config(self, config_file):
        self.log.debug("Parsing the jenkins config file")
        config = ConfigParser.ConfigParser()
        config.read(config_file)
        user = config.get('jenkins', 'user')
        password = config.get('jenkins', 'password')
        url = config.get('jenkins', 'url')
        return dict(url=url, user=user, password=password)



import logging

from cliff.command import Command


class Simple(Command):
    "A simple command that prints a message"

    log = logging.getLogger(__name__)

    def take_action(self, parsed_args):
        self.log.info('sending greeting')
        self.log.debug('debugging')
        self.app.stdout.write('hi!\n')



#!/usr/bin/env/python

PROJECT = 'jenkins-view-builder'

VERSION = '0.4.1'

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup

config = {
    'name': 'jenkins-view-builder',
    'version': '0.4.1',

    'description': 'Build jenkins views in YAML',

    'author': 'Piyush Srivastava',
    'author_email': 'piyush.0101@gmail.com',

    'url': 'https://github.com/piyush0101/jenkins-view-builder',
    'download_url': 'https://github.com/piyush0101/jenkins-view-builder/archive/0.4.1.tar.gz',

    'classifiers': [],

    'platforms': ['Any'],

    'scripts': [],

    'provides': [],

    'install_requires': ['cliff', 'PyYAML', 'argparse', 'cmd2',
        'gnureadline', 'prettytable', 'pyparsing', 'six',
        'stevedore', 'wsgiref', 'requests'],

    'packages': find_packages(),
    'include_package_data': True,
    'package_data': {'builder.converter.template': ['*.xml']},

    'entry_points' : {
            'console_scripts' : [
                    'jenkins-view-builder = builder.main:main',
                    ],
            'builder.commands' : [
                        'simple = builder.commands.simple:Simple',
                        'update = builder.commands.update:Update',
                        'test = builder.commands.test:Test',
                    ],
        },


    'zip_safe': False,
}

setup(**config)



import yaml
import os
import xml.etree.ElementTree as ET
from column_mapping import mapping


def convert_to_xml(yaml_str):
    yaml_dict = yaml.load(yaml_str)
    current_dir = os.path.dirname(os.path.realpath(__file__))
    template_path = os.path.join(current_dir,
                                 'templates/list_view_template.xml')
    root = ET.parse(template_path).getroot()
    set_name(root, yaml_dict)
    set_description(root, yaml_dict)
    set_jobs(root, yaml_dict)
    set_columns(root, yaml_dict)
    set_recurse(root, yaml_dict)
    xml = ET.tostring(root, method='xml', encoding="us-ascii")
    return (yaml_dict[0]['view']['name'],
            "<?xml version=\"1.0\" ?>" + xml)


def set_name(root, yaml_dict):
    name = root.find('name')
    name.text = yaml_dict[0]['view']['name']


def set_description(root, yaml_dict):
    if yaml_dict[0]['view']['description']:
        element = ET.Element('description')
        element.text = yaml_dict[0]['view']['description']
        root.append(element)


def set_jobs(root, yaml_dict):
    jobs_section = root.find('jobNames')
    jobs = yaml_dict[0]['view']['jobs']
    job_elements = [create_job_element(job)
                    for job in jobs]
    for element in job_elements:
        jobs_section.append(element)


def set_columns(root, yaml_dict):
    columns_section = root.find('columns')
    columns = yaml_dict[0]['view']['columns']
    column_elements = [create_column_element(column)
                       for column in columns]
    for element in column_elements:
        columns_section.append(element)


def set_recurse(root, yaml_dict):
    recurse = root.find('recurse')
    recurse.text = 'true' if yaml_dict[0]['view']['recurse'] else 'false'


def create_column_element(column):
    column_name = mapping.get(column, None)
    if column_name:
        column_element = ET.Element(column_name)
    else:
        raise Exception('Bad column name - %s' % column)
    return column_element


def create_job_element(name):
    job_element = ET.Element('string')
    job_element.text = name
    return job_element
